@@ -1,13 +1,12 @@
 from __future__ import absolute_import
-
 import json
 import logging
 
 import requests
-
 from lexicon.providers.base import Provider as BaseProvider
 
-logger = logging.getLogger(__name__)
+
+LOGGER = logging.getLogger(__name__)
 
 
 # Lexicon PowerDNS Provider
@@ -33,10 +32,13 @@ logger = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = []
 
+
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-token", help="specify token for authentication")
+    subparser.add_argument(
+        "--auth-token", help="specify token for authentication")
     subparser.add_argument("--pdns-server", help="URI for PowerDNS server")
-    subparser.add_argument("--pdns-server-id", help="Server ID to interact with")
+    subparser.add_argument(
+        "--pdns-server-id", help="Server ID to interact with")
 
 
 class Provider(BaseProvider):
@@ -96,7 +98,7 @@ class Provider(BaseProvider):
                             'content': self._unclean_content(rrset['type'], record['content']),
                             'id': self._make_identifier(rrset['type'], rrset['name'], record['content'])
                         })
-        logger.debug('list_records: %s', records)
+        LOGGER.debug('list_records: %s', records)
         return records
 
     def _clean_content(self, type, content):
@@ -146,7 +148,7 @@ class Provider(BaseProvider):
         update_data['name'] = self._fqdn_name(update_data['name'])
 
         request = {'rrsets': [update_data]}
-        logger.debug('request: %s', request)
+        LOGGER.debug('request: %s', request)
 
         self._patch('/zones/' + self.domain, data=request)
         self._zone_data = None
@@ -156,7 +158,7 @@ class Provider(BaseProvider):
         if identifier is not None:
             type, name, content = self._parse_identifier(identifier)
 
-        logger.debug("delete %s %s %s", type, name, content)
+        LOGGER.debug("delete %s %s %s", type, name, content)
         if type is None or name is None:
             raise Exception("Must specify at least both type and name")
 
@@ -179,7 +181,7 @@ class Provider(BaseProvider):
         update_data['records'] = new_records
 
         request = {'rrsets': [update_data]}
-        logger.debug('request: %s', request)
+        LOGGER.debug('request: %s', request)
 
         self._patch('/zones/' + self.domain, data=request)
         self._zone_data = None
@@ -203,6 +205,6 @@ class Provider(BaseProvider):
                                  'X-API-Key': self.api_key,
                                  'Content-Type': 'application/json'
                              })
-        logger.debug('response: %s', r.text)
+        LOGGER.debug('response: %s', r.text)
         r.raise_for_status()
         return r
